==> hinemos-2.1.0_src.tar.gz: hinemos-2.1.0_src/JobManagementUI/src/com/clustercontrol/jobmanagement/composite/JobTreeComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Tree;

import com.clustercontrol.jobmanagement.action.GetJobTree;
import com.clustercontrol.jobmanagement.action.GetJobTreeOneLevel;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;

/**
 * ֳإĥ꡼ݥå
 *  
 */
public class JobTreeComposite extends Composite {
    private TreeViewer m_viewer = null;

    private JobTreeItem m_selectItem = null;

    private boolean m_treeOnly = false;

    private String m_parentJobId = null;

    private String m_jobId = null;

    public JobTreeComposite(Composite parent, int style) {
        super(parent, style);

        m_treeOnly = false;

        initialize();
    }

    public JobTreeComposite(Composite parent, int style, boolean treeOnly) {
        super(parent, style);

        m_treeOnly = treeOnly;

        initialize();
    }

    public JobTreeComposite(Composite parent, int style, String parentJobId,
            String jobId) {
        super(parent, style);

        m_treeOnly = true;
        m_parentJobId = parentJobId;
        m_jobId = jobId;

        initialize();
    }

    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        Tree tree = new Tree(this, SWT.SINGLE | SWT.BORDER);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        tree.setLayoutData(gridData);

        m_viewer = new TreeViewer(tree);
        m_viewer.setContentProvider(new JobTreeContentProvider());
        m_viewer.setLabelProvider(new JobTreeLabelProvider());

        // 򥢥ƥ٥
        m_viewer.addSelectionChangedListener(new ISelectionChangedListener() {
            public void selectionChanged(SelectionChangedEvent event) {
                StructuredSelection selection = (StructuredSelection) event
                        .getSelection();

                m_selectItem = (JobTreeItem) selection.getFirstElement();
            }
        });

        update();
    }

    /**
     * ΥݥåȤѤĥ꡼ӥ塼֤ޤ
     * 
     * @return ĥ꡼ӥ塼
     */
    public TreeViewer getTreeViewer() {
        return m_viewer;
    }

    /**
     * ΥݥåȤѤĥ꡼֤ޤ
     * 
     * @return ĥ꡼
     */
    public Tree getTree() {
        return m_viewer.getTree();
    }

    /**
     * 
     * 
     * @since 1.0.0
     */
    public void update() {
        JobTreeItem jobTree = null;
        m_selectItem = null;

        //ְ
        if (m_jobId == null) {
            GetJobTree getJobTree = new GetJobTree();
            jobTree = getJobTree.getJobTree(m_treeOnly);
        } else {
            GetJobTreeOneLevel getJobTree = new GetJobTreeOneLevel();
            jobTree = getJobTree.getJobTreeOneLevel(m_parentJobId, m_jobId);
        }

        m_viewer.setInput(jobTree);

        //֥˥åȤΥ٥ޤŸ
        m_viewer.expandToLevel(2);
    }

    /**
     * 򤵤Ƥĥ꡼ƥ֤ޤ
     * 
     * @return ĥ꡼ƥ
     */
    public JobTreeItem getSelectItem() {
        return m_selectItem;
    }

    /**
     * 򤵤Ƥĥ꡼ƥ
     * 
     * @param item
     */
    public void setSelectItem(JobTreeItem item) {
        m_selectItem = item;
    }
}

==> hinemos-2.1.1_src.tar.gz: hinemos-2.1.1_src/JobManagementUI/src/com/clustercontrol/jobmanagement/composite/JobTreeComposite.java <==
/*
 
Copyright (C) 2006 NTT DATA Corporation
 
This program is free software; you can redistribute it and/or
Modify it under the terms of the GNU General Public License 
as published by the Free Software Foundation, version 2.
 
This program is distributed in the hope that it will be
useful, but WITHOUT ANY WARRANTY; without even the implied 
warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
PURPOSE.  See the GNU General Public License for more details.
 
*/

package com.clustercontrol.jobmanagement.composite;

import org.eclipse.jface.viewers.ISelectionChangedListener;
import org.eclipse.jface.viewers.SelectionChangedEvent;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.jface.viewers.TreeViewer;
import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Tree;

import com.clustercontrol.jobmanagement.action.GetJobTree;
import com.clustercontrol.jobmanagement.action.GetJobTreeOneLevel;
import com.clustercontrol.jobmanagement.bean.JobTreeItem;

/**
 * ジョブ階層ツリーコンポジット
 *  
 */
public class JobTreeComposite extends Composite {
    private TreeViewer m_viewer = null;

    private JobTreeItem m_selectItem = null;

    private boolean m_treeOnly = false;

    private String m_parentJobId = null;

    private String m_jobId = null;

    public JobTreeComposite(Composite parent, int style) {
        super(parent, style);

        m_treeOnly = false;

        initialize();
    }

    public JobTreeComposite(Composite parent, int style, boolean treeOnly) {
        super(parent, style);

        m_treeOnly = treeOnly;

        initialize();
    }

    public JobTreeComposite(Composite parent, int style, String parentJobId,
            String jobId) {
        super(parent, style);

        m_treeOnly = true;
        m_parentJobId = parentJobId;
        m_jobId = jobId;

        initialize();
    }

    private void initialize() {
        GridLayout layout = new GridLayout(1, true);
        this.setLayout(layout);
        layout.marginHeight = 0;
        layout.marginWidth = 0;

        Tree tree = new Tree(this, SWT.SINGLE | SWT.BORDER);
        GridData gridData = new GridData();
        gridData.horizontalAlignment = GridData.FILL;
        gridData.verticalAlignment = GridData.FILL;
        gridData.grabExcessHorizontalSpace = true;
        gridData.grabExcessVerticalSpace = true;
        tree.setLayoutData(gridData);

        m_viewer = new TreeViewer(tree);
        m_viewer.setContentProvider(new JobTreeContentProvider());
        m_viewer.setLabelProvider(new JobTreeLabelProvider());

        // 選択アイテム取得イベント定義
        m_viewer.addSelectionChangedListener(new ISelectionChangedListener() {
            public void selectionChanged(SelectionChangedEvent event) {
                StructuredSelection selection = (StructuredSelection) event
                        .getSelection();

                m_selectItem = (JobTreeItem) selection.getFirstElement();
            }
        });

        update();
    }

    /**
     * このコンポジットが利用するツリービューアを返します。
     * 
     * @return ツリービューア
     */
    public TreeViewer getTreeViewer() {
        return m_viewer;
    }

    /**
     * このコンポジットが利用するツリーを返します。
     * 
     * @return ツリー
     */
    public Tree getTree() {
        return m_viewer.getTree();
    }

    /**
     * 更新処理
     * 
     * @since 1.0.0
     */
    public void update() {
        JobTreeItem jobTree = null;
        m_selectItem = null;

        //ジョブ一覧情報取得
        if (m_jobId == null) {
            GetJobTree getJobTree = new GetJobTree();
            jobTree = getJobTree.getJobTree(m_treeOnly);
        } else {
            GetJobTreeOneLevel getJobTree = new GetJobTreeOneLevel();
            jobTree = getJobTree.getJobTreeOneLevel(m_parentJobId, m_jobId);
        }

        m_viewer.setInput(jobTree);

        //ジョブユニットのレベルまで展開
        m_viewer.expandToLevel(2);
    }

    /**
     * 現在選択されているツリーアイテムを返します。
     * 
     * @return ツリーアイテム
     */
    public JobTreeItem getSelectItem() {
        return m_selectItem;
    }

    /**
     * 現在選択されているツリーアイテムを設定
     * 
     * @param item
     */
    public void setSelectItem(JobTreeItem item) {
        m_selectItem = item;
    }
}
